@@ -2,6 +2,7 @@
     function (object.cca, object.xy, grain = 1, round.up = FALSE,
               permutations = 0) 
 {
+    EPS <- sqrt(.Machine$double.eps)
     if (inherits(object.cca, "mso")) {
         rm <- which(class(object.cca) == "mso")
         class(object.cca) <- class(object.cca)[-rm]
@@ -11,7 +12,14 @@
     N <- nrow(object$CA$Xbar)
     if (inherits(object, "rda")) 
         N <- 1
-    Dist <- dist(xy)
+    ## we expect xy are coordinates and calculate distances, but a
+    ## swift user may have supplied distances, and we use them.
+    ## However, we won't test for distances in square matrices, but
+    ## treat that as a user mistake and let it go.
+    if (inherits(xy, "dist"))
+        Dist <- xy
+    else
+        Dist <- dist(xy)
     object$grain <- grain
     if (round.up) 
         H <- ceiling(Dist/grain) * grain
@@ -76,7 +84,8 @@
         }
         perm <- sapply(1:nperm, function(take) permfunc(permat[take,]))
         object$vario$CA.signif <-
-            (rowSums(sweep(perm, 1, statistic, ">=")) + 1)/(nperm + 1)
+            (rowSums(sweep(perm, 1, statistic - EPS, ">=")) + 1)/
+                (nperm + 1)
         attr(object$vario, "control") <- attr(permat, "control")
     }
     object$call <- match.call()
