@@ -1,6 +1,7 @@
 `predict.cca` <-
     function (object, newdata, type = c("response", "wa", "sp", "lc", "working"), 
-              rank = "full", model = c("CCA", "CA"), scaling = FALSE, ...) 
+              rank = "full", model = c("CCA", "CA"), scaling = "none",
+              hill = FALSE, ...) 
 {
     type <- match.arg(type)
     model <- match.arg(model)
@@ -20,6 +21,8 @@
     if (is.null(w)) 
         w <- u
     slam <- diag(sqrt(object[[model]]$eig[1:take]), nrow = take)
+    ## process scaling arg, scaling used later so needs to be a numeric
+    scaling <- scalingType(scaling = scaling, hill = hill)
     if (type %in%  c("response", "working")) {
         Xbar <- 0
         if (!missing(newdata)) {
@@ -31,8 +34,6 @@
         }
         if (take > 0) 
             Xbar <- u %*% slam %*% t(v)
-        if (!is.null(object$pCCA)) 
-            warning("Conditional ('partial') component ignored")
         rc <- outer(rs, cs)
         if (type == "response") 
             out <- (Xbar + 1) * rc * gtot
@@ -58,7 +59,7 @@
             u <- u[, 1:take, drop = FALSE]
         }
         out <- u
-        if (scaling) {
+        if (scaling) {      # implicit conversion "none" == 0 == FALSE
             scal <- list(diag(slam), 1, sqrt(diag(slam)))[[abs(scaling)]]
             out <- sweep(out, 2, scal, "*")
             if (scaling < 0) {
@@ -89,7 +90,7 @@
             w <- sweep(w, 2, diag(slam), "/")
         }
         out <- w
-        if (scaling) {
+        if (scaling) {      # implicit conversion "none" == 0 == FALSE
             scal <- list(diag(slam), 1, sqrt(diag(slam)))[[abs(scaling)]]
             out <- sweep(out, 2, scal, "*")
             if (scaling < 0) {
@@ -116,7 +117,7 @@
             v <- sweep(v, 2, diag(slam), "/")
         }
         out <- v
-        if (scaling) {
+        if (scaling) {      # implicit conversion "none" == 0 == FALSE
             scal <- list(1, diag(slam), sqrt(diag(slam)))[[abs(scaling)]]
             out <- sweep(out, 2, scal, "*")
             if (scaling < 0) {
